==> kubernetes-model-gatewayapi-6.5.1-sources.jar: io/fabric8/kubernetes/api/model/gatewayapi/v1alpha2/GRPCBackendRefFluent.java <==
package io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface GRPCBackendRefFluent<A extends GRPCBackendRefFluent<A>> extends Fluent<A>{
  public A addToFilters(Integer index,GRPCRouteFilter item);
  public A setToFilters(Integer index,GRPCRouteFilter item);
  public A addToFilters(io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2.GRPCRouteFilter... items);
  public A addAllToFilters(Collection<GRPCRouteFilter> items);
  public A removeFromFilters(io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2.GRPCRouteFilter... items);
  public A removeAllFromFilters(Collection<GRPCRouteFilter> items);
  public A removeMatchingFromFilters(Predicate<GRPCRouteFilterBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildFilters instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<GRPCRouteFilter> getFilters();
  public List<GRPCRouteFilter> buildFilters();
  public GRPCRouteFilter buildFilter(Integer index);
  public GRPCRouteFilter buildFirstFilter();
  public GRPCRouteFilter buildLastFilter();
  public GRPCRouteFilter buildMatchingFilter(Predicate<GRPCRouteFilterBuilder> predicate);
  public Boolean hasMatchingFilter(Predicate<GRPCRouteFilterBuilder> predicate);
  public A withFilters(List<GRPCRouteFilter> filters);
  public A withFilters(io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2.GRPCRouteFilter... filters);
  public Boolean hasFilters();
  public GRPCBackendRefFluent.FiltersNested<A> addNewFilter();
  public GRPCBackendRefFluent.FiltersNested<A> addNewFilterLike(GRPCRouteFilter item);
  public GRPCBackendRefFluent.FiltersNested<A> setNewFilterLike(Integer index,GRPCRouteFilter item);
  public GRPCBackendRefFluent.FiltersNested<A> editFilter(Integer index);
  public GRPCBackendRefFluent.FiltersNested<A> editFirstFilter();
  public GRPCBackendRefFluent.FiltersNested<A> editLastFilter();
  public GRPCBackendRefFluent.FiltersNested<A> editMatchingFilter(Predicate<GRPCRouteFilterBuilder> predicate);
  public String getGroup();
  public A withGroup(String group);
  public Boolean hasGroup();
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public String getName();
  public A withName(String name);
  public Boolean hasName();
  public String getNamespace();
  public A withNamespace(String namespace);
  public Boolean hasNamespace();
  public Integer getPort();
  public A withPort(Integer port);
  public Boolean hasPort();
  public Integer getWeight();
  public A withWeight(Integer weight);
  public Boolean hasWeight();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface FiltersNested<N> extends Nested<N>,GRPCRouteFilterFluent<GRPCBackendRefFluent.FiltersNested<N>>{
    public N and();
    public N endFilter();
    
  }
  
}

==> kubernetes-model-gatewayapi-6.7.0-sources.jar: io/fabric8/kubernetes/api/model/gatewayapi/v1alpha2/GRPCBackendRefFluent.java <==
package io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface GRPCBackendRefFluent<A extends GRPCBackendRefFluent<A>> extends Fluent<A>{
  public A addToFilters(int index,GRPCRouteFilter item);
  public A setToFilters(int index,GRPCRouteFilter item);
  public A addToFilters(io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2.GRPCRouteFilter... items);
  public A addAllToFilters(Collection<GRPCRouteFilter> items);
  public A removeFromFilters(io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2.GRPCRouteFilter... items);
  public A removeAllFromFilters(Collection<GRPCRouteFilter> items);
  public A removeMatchingFromFilters(Predicate<GRPCRouteFilterBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildFilters instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<GRPCRouteFilter> getFilters();
  public List<GRPCRouteFilter> buildFilters();
  public GRPCRouteFilter buildFilter(int index);
  public GRPCRouteFilter buildFirstFilter();
  public GRPCRouteFilter buildLastFilter();
  public GRPCRouteFilter buildMatchingFilter(Predicate<GRPCRouteFilterBuilder> predicate);
  public Boolean hasMatchingFilter(Predicate<GRPCRouteFilterBuilder> predicate);
  public A withFilters(List<GRPCRouteFilter> filters);
  public A withFilters(io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2.GRPCRouteFilter... filters);
  public Boolean hasFilters();
  public GRPCBackendRefFluent.FiltersNested<A> addNewFilter();
  public GRPCBackendRefFluent.FiltersNested<A> addNewFilterLike(GRPCRouteFilter item);
  public GRPCBackendRefFluent.FiltersNested<A> setNewFilterLike(int index,GRPCRouteFilter item);
  public GRPCBackendRefFluent.FiltersNested<A> editFilter(int index);
  public GRPCBackendRefFluent.FiltersNested<A> editFirstFilter();
  public GRPCBackendRefFluent.FiltersNested<A> editLastFilter();
  public GRPCBackendRefFluent.FiltersNested<A> editMatchingFilter(Predicate<GRPCRouteFilterBuilder> predicate);
  public String getGroup();
  public A withGroup(String group);
  public Boolean hasGroup();
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public String getName();
  public A withName(String name);
  public Boolean hasName();
  public String getNamespace();
  public A withNamespace(String namespace);
  public Boolean hasNamespace();
  public Integer getPort();
  public A withPort(Integer port);
  public Boolean hasPort();
  public Integer getWeight();
  public A withWeight(Integer weight);
  public Boolean hasWeight();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface FiltersNested<N> extends Nested<N>,GRPCRouteFilterFluent<GRPCBackendRefFluent.FiltersNested<N>>{
    public N and();
    public N endFilter();
    
  }
  
}
